#[repr(u8)]pub enum Valid {
VALID_0 = 0,
VALID_1 = 1,
}Variants
VALID_0 = 0
There is no touch detected after measurement, indicates that the measured value is not valid
VALID_1 = 1
There is touch detection after measurement, indicates that the measure is valid
Implementations